
function _write_html(vspec::Union{SGPlot, SGPanel, SGGrid})
    out_html = tempname() * ".html"
    html_out = """
    <!DOCTYPE html>
    <html>
    <head>
        <title>Embedding Vega-Lite</title>
        <script src="https://cdn.jsdelivr.net/npm/vega@5"></script>
        <script src="https://cdn.jsdelivr.net/npm/vega-lite@5"></script>
        <script src="https://cdn.jsdelivr.net/npm/vega-embed@6"></script>
    </head>
    <body>
        <div id="vis"></div>

        <script>
        var spec = $(json(vspec.json_spec));
        vegaEmbed('#vis', spec);
        </script>
    </body>
    </html>
    """
    write(out_html, html_out)
    out_html
end

function _write_script(io::IO, vspec::Union{SGPlot, SGPanel, SGGrid})
    divid=string(rand(UInt128), base=16)
    write(io, 
    """
    <script src="https://cdn.jsdelivr.net/npm/vega@5"></script>
    <script src="https://cdn.jsdelivr.net/npm/vega-lite@5"></script>
    <script src="https://cdn.jsdelivr.net/npm/vega-embed@6"></script>
    <div id="$divid"></div>
    <script>
        var spec = $(json(vspec.json_spec));
        vegaEmbed('#$divid', spec);
    </script>
    """
    )
    nothing
end


function Base.display(::REPL.REPLDisplay, vspec::Union{SGPlot, SGPanel, SGGrid})
    tmppath = _write_html(vspec)
    launch_browser(tmppath) # Open the browser
end

Base.showable(::MIME"text/html", ::Union{SGPlot, SGPanel, SGGrid}) = isdefined(Main, :PlutoRunner)
function Base.show(io::IO, ::MIME"text/html", vspec::Union{SGPlot, SGPanel, SGGrid})
    _write_script(io, vspec)
end
